@@ -193,7 +193,7 @@ class Pool(object):
         return ret
     
     def resize(self, size):
-        assert size > 0
+        assert size >= 0
         self._processes = size
         diff = self._processes - len(self._pool)
         if diff < 0:
